@@ -2,12 +2,13 @@
 #'
 #' Retrieve code from `teal_data` object.
 #'
-#' Retrieve code stored in `@code`, which (in principle) can be used to recreate all objects found in `@env`.
-#' Use `datanames` to limit the code to one or more of the datasets enumerated in `@datanames`.
-#' If the code has not passed verification (with [`verify()`]), a warning will be prepended.
+#' Retrieve code stored in `@code`, which (in principle) can be used to recreate
+#' all objects found in the environment (`@.xData`).
+#' Use `names` to limit the code to one or more of the datasets enumerated in
+#' the environment.
 #'
 #' @section Extracting dataset-specific code:
-#' When `datanames` is specified, the code returned will be limited  to the lines needed to _create_
+#' When `names` is specified, the code returned will be limited  to the lines needed to _create_
 #' the requested datasets. The code stored in the `@code` slot is analyzed statically to determine
 #' which lines the datasets of interest depend upon. The analysis works well when objects are created
 #' with standard infix assignment operators (see `?assignOps`) but it can fail in some situations.
@@ -24,10 +25,10 @@
 #'     x <- 0
 #'     y <- foo(x)
 #'   })
-#' get_code(data, datanames = "y")
+#' get_code(data, names = "y")
 #' ```
-#' `x` has no dependencies, so `get_code(data, datanames = "x")` will return only the second call.\cr
-#' `y` depends on `x` and `foo`, so `get_code(data, datanames = "y")` will contain all three calls.
+#' `x` has no dependencies, so `get_code(data, names = "x")` will return only the second call.\cr
+#' `y` depends on `x` and `foo`, so `get_code(data, names = "y")` will contain all three calls.
 #'
 #' _Case 2: Some objects are created by a function's side effects._
 #' ```r
@@ -40,10 +41,10 @@
 #'     foo()
 #'     y <- x
 #'   })
-#' get_code(data, datanames = "y")
+#' get_code(data, names = "y")
 #' ```
 #' Here, `y` depends on `x` but `x` is modified by `foo` as a side effect (not by reassignment)
-#' and so `get_code(data, datanames = "y")` will not return the `foo()` call.\cr
+#' and so `get_code(data, names = "y")` will not return the `foo()` call.\cr
 #' To overcome this limitation, code dependencies can be specified manually.
 #' Lines where side effects occur can be flagged by adding "`# @linksto <object name>`" at the end.\cr
 #' Note that `within` evaluates code passed to `expr` as is and comments are ignored.
@@ -59,7 +60,7 @@
 #'     foo() # @linksto x
 #'     y <- x
 #'   ")
-#' get_code(data, datanames = "y")
+#' get_code(data, names = "y")
 #' ```
 #' Now the `foo()` call will be properly included in the code required to recreate `y`.
 #'
@@ -73,7 +74,9 @@
 #'
 #'
 #' @param object (`teal_data`)
-#' @param datanames `r lifecycle::badge("experimental")` (`character`) vector of dataset names to return the code for.
+#' @param datanames `r lifecycle::badge("deprecated")` (`character`) vector of dataset names to return the code for.
+#' For more details see the "Extracting dataset-specific code" section. Use `names` instead.
+#' @param names (`character`) Successor of `datanames`. Vector of dataset names to return the code for.
 #' For more details see the "Extracting dataset-specific code" section.
 #' @param deparse (`logical`) flag specifying whether to return code as `character` (`deparse = TRUE`) or as
 #' `expression` (`deparse = FALSE`).
@@ -82,7 +85,7 @@
 #' `code` but are passed in `datanames`. To remove the warning, set `check_names = FALSE`.
 #'
 #' @return
-#' Either a character string or an expression. If `datanames` is used to request a specific dataset,
+#' Either a character string or an expression. If `names` is used to request a specific dataset,
 #' only code that _creates_ that dataset (not code that uses it) is returned. Otherwise, all contents of `@code`.
 #'
 #' @examples
@@ -93,8 +96,8 @@
 #'   c <- list(x = 2)
 #' })
 #' get_code(tdata1)
-#' get_code(tdata1, datanames = "a")
-#' get_code(tdata1, datanames = "b")
+#' get_code(tdata1, names = "a")
+#' get_code(tdata1, names = "b")
 #'
 #' tdata2 <- teal_data(x1 = iris, code = "x1 <- iris")
 #' get_code(tdata2)
@@ -104,27 +107,26 @@
 #' @aliases get_code,teal_data-method
 #'
 #' @export
-setMethod("get_code", signature = "teal_data", definition = function(object, deparse = TRUE, datanames = NULL, ...) {
-  checkmate::assert_character(datanames, min.len = 1L, null.ok = TRUE)
-  checkmate::assert_flag(deparse)
-
-  code <- if (!is.null(datanames)) {
-    get_code_dependency(object@code, datanames, ...)
-  } else {
-    object@code
-  }
-
-  if (!object@verified) {
-    code <- c("warning('Code was not verified for reproducibility.')", code)
-  }
-
-  if (deparse) {
-    if (length(code) == 0) {
-      code
-    } else {
-      paste(code, collapse = "\n")
+setMethod("get_code",
+  signature = "teal_data",
+  definition = function(object, deparse = TRUE, names = NULL, datanames = lifecycle::deprecated(), ...) {
+    if (lifecycle::is_present(datanames)) {
+      lifecycle::deprecate_warn(
+        when = "0.7.0",
+        what = "teal.data::get_code(datanames)",
+        with = "teal.code::get_code(names)",
+        always = TRUE
+      )
+      names <- datanames
     }
-  } else {
-    parse(text = paste(c("{", code, "}"), collapse = "\n"), keep.source = TRUE)
+
+    if (!is.null(names) && lifecycle::is_present(datanames)) {
+      stop("'names' shouldn't be specified with deprecated 'datanames' parameter.")
+    }
+
+    checkmate::assert_character(names, min.len = 1L, null.ok = TRUE)
+    checkmate::assert_flag(deparse)
+
+    methods::callNextMethod(object = object, deparse = deparse, names = names, ...)
   }
-})
+)
